%global upver 1.4
%global uprel 17

Name:           mona
Version:        %{upver}r%{uprel}
Release:        1%{?dist}
Summary:        A decision procedure for the WS1S and WS2S logics

Group:          Applications/Engineering
License:        GPLv2+
URL:            http://www.brics.dk/mona/
Source0:        http://www.brics.dk/mona/download/%{name}-%{upver}-%{uprel}.tar.gz
Source1:        http://www.brics.dk/mona/mona14.pdf

BuildRequires:  emacs
BuildRequires:  emacs-el
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  xemacs
BuildRequires:  xemacs-devel
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description
MONA is a tool that translates formulas in the logics WS1S or WS2S into
finite-state automata represented by BDDs.  The formulas may express search
patterns, temporal properties of reactive systems, parse tree constraints,
etc.  MONA also analyses the automaton resulting from the compilation, and
determines whether the formula is valid and, if the formula is not valid,
generates a counterexample.

%package libs
Group:          Applications/Engineering
Summary:        Supporting libraries for Mona

%description libs
Supporting libraries for Mona.

%package devel
Group:          Applications/Engineering
Summary:        Header files for developing applications with Mona
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
Header files for developing applications that use the Mona libraries.

%package examples
Group:          Applications/Engineering
Summary:        Example Mona source files and C programs
Requires:       %{name}-libs = %{version}-%{release}
BuildArch:      noarch

%description examples
Example Mona source files, for use with the mona executable, and also sample C
programs that access the Mona library interfaces.

%package emacs
Group:          Applications/Engineering
Summary:        Emacs mode for editing Mona files
Requires:       %{name}-libs = %{version}-%{release}
Requires:       emacs(bin) >= %{_emacs_version}
BuildArch:      noarch

# These can be removed once F22 reaches EOL
Obsoletes:      %{name}-emacs-el < 1.4r16-1
Provides:       %{name}-emacs-el = %{version}-%{release}

%description emacs
Emacs mode for editing Mona files.

%package xemacs
Group:          Applications/Engineering
Summary:        XEmacs mode for editing Mona files
Requires:       %{name}-libs = %{version}-%{release}
Requires:       xemacs(bin) >= %{_xemacs_version}
BuildArch:      noarch

# These can be removed once F22 reaches EOL
Obsoletes:      %{name}-xemacs-el < 1.4r16-1
Provides:       %{name}-xemacs-el = %{version}-%{release}

%description xemacs
XEmacs mode for editing Mona files.

%prep
%setup -q -n %{name}-%{upver}
cp -p %{SOURCE1} .

# Make an intentionally-undefined symbol weak
sed '/^using/i#pragma weak guide\n' Front/lib.cpp > Front/lib.cpp.new
touch -r Front/lib.cpp Front/lib.cpp.new
mv -v Front/lib.cpp.new Front/lib.cpp

%build
%configure --disable-static
make %{?_smp_mflags} CFLAGS="${RPM_OPT_FLAGS} -DNDEBUG" \
  CXXFLAGS="${RPM_OPT_FLAGS} -DNDEBUG"

%install
make install DESTDIR=$RPM_BUILD_ROOT

# Get rid of the .la files; we don't want them
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la

# Install the examples
cp -p Examples/bdd_example $RPM_BUILD_ROOT%{_bindir}
cp -p Examples/gta_example $RPM_BUILD_ROOT%{_bindir}
cp -p Examples/presburger_analysis $RPM_BUILD_ROOT%{_bindir}
cp -p Examples/presburger_transduction $RPM_BUILD_ROOT%{_bindir}

# Move the Emacs lisp file to the right places
mkdir -p $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/mona
mkdir -p $RPM_BUILD_ROOT%{_datadir}/xemacs/site-packages/lisp

cd $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/mona
cp -p $RPM_BUILD_ROOT%{_datadir}/mona-mode.el .
%_emacs_bytecompile mona-mode.el

cd $RPM_BUILD_ROOT%{_datadir}/xemacs/site-packages/lisp
mv $RPM_BUILD_ROOT%{_datadir}/mona-mode.el .
%_xemacs_bytecompile mona-mode.el

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%files
%doc mona14.pdf
%{_bindir}/mona
%{_bindir}/dfa2dot
%{_bindir}/gta2dot
%{_mandir}/man1/*

%files devel
%{_includedir}/mona
%{_libdir}/*.so

%files examples
%doc Examples/*.mona Examples/bdd_volatility
%{_bindir}/bdd_example
%{_bindir}/gta_example
%{_bindir}/presburger_analysis
%{_bindir}/presburger_transduction

%files libs
%doc AUTHORS ChangeLog NEWS README
%license COPYING
%{_libdir}/*.so.*

%files emacs
%dir %{_emacs_sitelispdir}/mona
%{_emacs_sitelispdir}/mona/mona-mode.el*

%files xemacs
%dir %{_xemacs_sitelispdir}
%{_xemacs_sitelispdir}/mona-mode.el*

%changelog
* Mon Mar 28 2016 Jerry James <loganjerry@gmail.com> - 1.4r17-1
- Update to 1.4-17

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.4r16-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Oct  8 2015 Jerry James <loganjerry@gmail.com> - 1.4r16-1
- Update to 1.4-16

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4r15-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 1.4r15-6
- Rebuilt for GCC 5 C++11 ABI change

* Tue Feb 10 2015 Jerry James <loganjerry@gmail.com> - 1.4r15-5
- Add -inline patch to fix a build failure with gcc 5.0
- Use the license macro

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4r15-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4r15-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4r15-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul  2 2013 Jerry James <loganjerry@gmail.com> - 1.4r15-1
- Update to 1.4-15

* Mon Apr 29 2013 Jerry James <loganjerry@gmail.com> - 1.4r14-1
- Update to 1.4-14
- Make "guide", which is undefined on purpose, a weak symbol

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4r13-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4r13-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan  6 2012 Jerry James <loganjerry@gmail.com> - 1.4r13-5
- Rebuild for GCC 4.7
- Spec file cleanups

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4r13-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Nov 29 2010 Jerry James <loganjerry@gmail.com> - 1.4r13-4
- Move COPYING and other docs to -libs, which is required by the main package.
- Remove unnecessary libtool BR.
- Remove BuildRoot tag.

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4r13-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4r13-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Aug 11 2008 Jerry James <loganjerry@gmail.com> - 1.4r13-1
- Update to 1.4-13

* Tue Jun 17 2008 Jerry James <loganjerry@gmail.com> - 1.4r11-1
- Update to 1.4-11
- Add the user manual to the main package docs

* Mon Mar 10 2008 Jerry James <loganjerry@gmail.com> - 1.4r10-1
- Initial RPM
